%define debug_package %{nil}
%bcond_with testsuite

%define devname %mklibname -d dyninst


Summary: An API for Run-time Code Generation
License: LGPLv2+
Name: dyninst
Group: Development/C
Release: %mkrel 1
URL: http://www.dyninst.org
Version: 9.1.0
Exclusiveos: linux
#dyninst only knows the following architectures
ExclusiveArch: %{ix86} x86_64 ppc ppc64

Source0: http://www.paradyn.org/release%{version}/DyninstAPI-%{version}.tgz
Source1: http://www.paradyn.org/release%{version}/Testsuite-%{version}.tgz
Patch1: dyninst-export.patch

%global dyninst_base DyninstAPI-%{version}
%global testsuite_base Testsuite-%{version}

BuildRequires: libdwarf-devel >= 20111030
BuildRequires: elfutils-devel
BuildRequires: boost-devel
BuildRequires: binutils-devel
BuildRequires: cmake

# Extra requires just for the testsuite
BuildRequires: gcc-gfortran glibc-static-devel libstdc++6-static-devel nasm

# Testsuite files should not provide/require anything
%{?filter_setup:
%filter_provides_in %{_libdir}/dyninst/testsuite/
%filter_requires_in %{_libdir}/dyninst/testsuite/
%filter_setup
}

%description

Dyninst is an Application Program Interface (API) to permit the insertion of
code into a running program. The API also permits changing or removing
subroutine calls from the application program. Run-time code changes are
useful to support a variety of applications including debugging, performance
monitoring, and to support composing applications out of existing packages.
The goal of this API is to provide a machine independent interface to permit
the creation of tools and applications that use run-time code patching.

%package doc
Summary: Documentation for using the Dyninst API
Group: Documentation
%description doc
dyninst-doc contains API documentation for the Dyninst libraries.

%package -n %devname
Summary: Header files for the compiling programs with Dyninst
Group: Development/C
Requires: dyninst = %{version}-%{release}
Requires: boost-devel
Provides: %{name}-devel = %{version}-%{release}

%description -n %devname
dyninst-devel includes the C header files that specify the Dyninst user-space
libraries and interfaces. This is required for rebuilding any program
that uses Dyninst.

%package static
Summary: Static libraries for the compiling programs with Dyninst
Group: Development/C
Requires: dyninst-devel = %{version}-%{release}
%description static
dyninst-static includes the static versions of the library files for
the dyninst user-space libraries and interfaces.

%if %with testsuite
%package testsuite
Summary: Programs for testing Dyninst
Group: Development/C
Requires: dyninst = %{version}-%{release}
Requires: dyninst-devel = %{version}-%{release}
Requires: dyninst-static = %{version}-%{release}
Requires: glibc-static
%description testsuite
dyninst-testsuite includes the test harness and target programs for
making sure that dyninst works properly.
%endif

%prep
%setup -q -n %{name}-%{version} -c
%setup -q -T -D -a 1

%patch1 -p0 -b .export

%build

cd %{dyninst_base}

%cmake \
 -DENABLE_STATIC_LIBS=1 \
 -DINSTALL_LIB_DIR:PATH=%{_libdir}/dyninst \
 -DINSTALL_INCLUDE_DIR:PATH=%{_includedir}/dyninst \
 -DINSTALL_CMAKE_DIR:PATH=%{_libdir}/cmake/Dyninst \
 -DCMAKE_BUILD_TYPE=None \
 -DCMAKE_SKIP_RPATH:BOOL=YES
%make_build

# Hack to install dyninst nearby, so the testsuite can use it
make DESTDIR=../install install
find ../install -name '*.cmake' -execdir \
  sed -i -e 's!%{_prefix}!../install&!' '{}' '+'
cd ..

%if %with testsuite
cd ../%{testsuite_base}
%cmake \
 -DDyninst_DIR:PATH=$PWD/../install%{_libdir}/cmake/Dyninst \
 -DINSTALL_DIR:PATH=%{_libdir}/dyninst/testsuite \
 -DCMAKE_BUILD_TYPE:STRING=Debug \
 -DCMAKE_SKIP_RPATH:BOOL=YES
%make_build
%endif

%install

cd %{dyninst_base}
pushd build
%make_install
popd

# It doesn't install docs the way we want, so remove them.
# We'll just grab the pdfs later, directly from the build dir.
rm -fv %{buildroot}%{_docdir}/*-%{version}.pdf

%if %with testsuite
cd ../%{testsuite_base}
%make_install
%endif

mkdir -p %{buildroot}/etc/ld.so.conf.d
echo "%{_libdir}/dyninst" > %{buildroot}/etc/ld.so.conf.d/%{name}-%{_arch}.conf

%if %with testsuite
# Ugly hack to mask testsuite files from debuginfo extraction.  Running the
# testsuite requires debuginfo, so extraction is useless.  However, debuginfo
# extraction is still nice for the main libraries, so we don't want to disable
# it package-wide.  The permissions are restored by attr(755,-,-) in files.
find %{buildroot}%{_libdir}/dyninst/testsuite/ \
  -type f '!' -name '*.a' -execdir chmod 644 '{}' '+'
%endif


%files
%dir %{_libdir}/dyninst
%{_libdir}/dyninst/*.so.*

%doc %{dyninst_base}/COPYRIGHT
%doc %{dyninst_base}/LGPL

%config(noreplace) /etc/ld.so.conf.d/*

%files doc
%doc %{dyninst_base}/dynC_API/doc/dynC_API.pdf
%doc %{dyninst_base}/dyninstAPI/doc/dyninstAPI.pdf
%doc %{dyninst_base}/instructionAPI/doc/instructionAPI.pdf
%doc %{dyninst_base}/parseAPI/doc/parseAPI.pdf
%doc %{dyninst_base}/patchAPI/doc/patchAPI.pdf
%doc %{dyninst_base}/proccontrol/doc/proccontrol.pdf
%doc %{dyninst_base}/stackwalk/doc/stackwalk.pdf
%doc %{dyninst_base}/symtabAPI/doc/symtabAPI.pdf

%files -n %devname
%{_includedir}/dyninst
%{_libdir}/dyninst/*.so
%dir %{_libdir}/cmake
%{_libdir}/cmake/Dyninst

%files static
%{_libdir}/dyninst/*.a

%if %with testsuite
%files testsuite
#{_bindir}/parseThat
%dir %{_libdir}/dyninst/testsuite/
# Restore the permissions that were hacked out above, during install.
%attr(755,root,root) %{_libdir}/dyninst/testsuite/*
%attr(644,root,root) %{_libdir}/dyninst/testsuite/*.a
%endif



%changelog
* Tue May 17 2016 tv <tv> 9.1.0-1.mga6
+ Revision: 1016489
- imported package dyninst

